@@ -111,7 +111,7 @@ package Text::BibTeX::BibStructure;
 use strict;
 use vars qw(@ISA $VERSION);
 @ISA = qw(Text::BibTeX::Structure);
-$VERSION = '0.75';
+$VERSION = '0.78';
 
 =head1 STRUCTURE OPTIONS
 
@@ -450,33 +450,13 @@ package Text::BibTeX::BibEntry;
 use strict;
 use vars qw(@ISA $VERSION);
 
-$VERSION = '0.75';
+$VERSION = '0.78';
 
 use Text::BibTeX::BibSort;
 use Text::BibTeX::BibFormat;
 
 @ISA = qw(Text::BibTeX::BibSort Text::BibTeX::BibFormat);
-
-# Pre-define the "month name" macros for compatibility with BibTeX.
-# This ignores all sorts of issues, like internationalization and
-# abbreviation.  
-my %month_names = 
-   ('jan' => 'January',
-    'feb' => 'February',
-    'mar' => 'March',
-    'apr' => 'April',
-    'may' => 'May',
-    'jun' => 'June',
-    'jul' => 'July',
-    'aug' => 'August',
-    'sep' => 'September',
-    'oct' => 'October',
-    'nov' => 'November',
-    'dec' => 'December');
-
-my ($macro, $expansion);
-Text::BibTeX::add_macro_text ($macro, $expansion)
-   while (($macro, $expansion) = each %month_names);    
+ 
 
 1;
 
